changeset 2362:482d3fb47d80

Renamed localrepo.undo() to rollback() and talk about "rollback information".
author Thomas Arendsen Hein <thomas@intevation.de>
date Thu, 01 Jun 2006 19:08:29 +0200
parents d3adb454c5a9
children fa4c11751367 46ec76f80e18 280fde4b8701 62ce297f214f
files mercurial/commands.py mercurial/localrepo.py
diffstat 2 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/mercurial/commands.py	Thu Jun 01 18:36:32 2006 +0200
+++ b/mercurial/commands.py	Thu Jun 01 19:08:29 2006 +0200
@@ -2432,7 +2432,7 @@
     repository; for example an in-progress pull from the repository
     may fail if a rollback is performed.
     """
-    repo.undo()
+    repo.rollback()
 
 def root(ui, repo):
     """print the root (top) of the current working dir
@@ -2757,7 +2757,7 @@
     instructions, see the rollback command.
     """
     ui.warn(_('(the undo command is deprecated; use rollback instead)\n'))
-    repo.undo()
+    repo.rollback()
 
 def update(ui, repo, node=None, merge=False, clean=False, force=None,
            branch=None, **opts):
--- a/mercurial/localrepo.py	Thu Jun 01 18:36:32 2006 +0200
+++ b/mercurial/localrepo.py	Thu Jun 01 19:08:29 2006 +0200
@@ -303,7 +303,7 @@
         if tr != None and tr.running():
             return tr.nest()
 
         # save dirstate for undo
         try:
             ds = self.opener("dirstate").read()
         except IOError:
@@ -327,7 +327,7 @@
             self.ui.warn(_("no interrupted transaction available\n"))
             return False
 
-    def undo(self, wlock=None):
+    def rollback(self, wlock=None):
         if not wlock:
             wlock = self.wlock()
         l = self.lock()
@@ -338,7 +338,7 @@
             self.reload()
             self.wreload()
         else:
-            self.ui.warn(_("no undo information available\n"))
+            self.ui.warn(_("no rollback information available\n"))
 
     def wreload(self):
         self.dirstate.read()
@@ -303,7 +303,7 @@
             return tr.nest()
 
-        # save dirstate for undo
+        # save dirstate for rollback
         try:
             ds = self.opener("dirstate").read()